"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.QuestionnaireMigrator = exports.QuestionnaireData = void 0;
const crypto_1 = __importDefault(require("crypto"));
const VersionedObject_js_1 = require("../../businessObjects/versioned/VersionedObject.js");
const index_js_1 = require("../../primitives/index.js");
class QuestionnaireData extends VersionedObject_js_1.VersionedObject {
    constructor(id, questions, title, questionHashes, description, image) {
        super();
        this.id = id;
        this.questions = questions;
        this.title = title;
        this.questionHashes = questionHashes;
        this.description = description;
        this.image = image;
    }
    getVersion() {
        return QuestionnaireData.CURRENT_VERSION;
    }
}
exports.QuestionnaireData = QuestionnaireData;
QuestionnaireData.CURRENT_VERSION = 2;
class QuestionnaireMigrator extends VersionedObject_js_1.VersionedObjectMigrator {
    getCurrentVersion() {
        return QuestionnaireData.CURRENT_VERSION;
    }
    factory(data) {
        return new QuestionnaireData(data.id, data.questions, data.title, data.questionHashes, data.description, data.image);
    }
    getUpgradeFunctions() {
        return new Map([
            [
                1,
                (data) => {
                    if ("status" in data) {
                        delete data.status;
                    }
                    data.questionHashes = data.questions?.map(({ index, ...question }) => {
                        const questionString = JSON.stringify(question, (key, value) => {
                            if (value instanceof Map) {
                                return {
                                    dataType: "Map",
                                    value: Array.from(value.entries()),
                                };
                            }
                            else if (value instanceof Set) {
                                return {
                                    dataType: "Set",
                                    value: [...value],
                                };
                            }
                            else if (value instanceof BigInt) {
                                return {
                                    dataType: "BigInt",
                                    value: value.toString(),
                                };
                            }
                            else if (typeof value == "bigint") {
                                return {
                                    dataType: "bigint",
                                    value: BigInt(value).toString(),
                                };
                            }
                            else {
                                return value;
                            }
                        });
                        const questionHash = crypto_1.default.createHash("sha256")
                            .update(questionString)
                            .digest("hex");
                        return [index, (0, index_js_1.SHA256Hash)(questionHash)];
                    });
                    return data;
                },
            ],
        ]);
    }
}
exports.QuestionnaireMigrator = QuestionnaireMigrator;
//# sourceMappingURL=QuestionnaireMigrator.js.map